summaryrefslogtreecommitdiff
path: root/src/code/z_camera.c
diff options
context:
space:
mode:
authorDragorn421 <Dragorn421@users.noreply.github.com>2022-08-29 19:52:42 +0200
committerGitHub <noreply@github.com>2022-08-29 13:52:42 -0400
commit7cfee3d8a92f5c80e9fa15ec5874b8105c8450ee (patch)
treef1b2b2d1b12f2395a8a48613542f964cf2455780 /src/code/z_camera.c
parent0d52a4aebdd40562cc8653dc95e2e07528019c9b (diff)
Doc pass on bgcheck-waterbox properties (#1288)
* Doc pass on bgcheck-waterbox properties * `WATERBOX_ROOM_INDEX...` -> `WATERBOX_ROOM...` * Fix `WATERBOX_PROPERTIES` macro (was completely wrong) * `((setFlag19) & 1) << WATERBOX_FLAG_19_SHIFT` instead of ternary * Fix `WATERBOX_PROPERTIES` macro (hopefully for good)
Diffstat (limited to 'src/code/z_camera.c')
-rw-r--r--src/code/z_camera.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/code/z_camera.c b/src/code/z_camera.c
index ee0b45eb5..1dd5b3768 100644
--- a/src/code/z_camera.c
+++ b/src/code/z_camera.c
@@ -540,11 +540,11 @@ s32 Camera_GetWaterBoxBgCamIndex(Camera* camera, f32* waterY) {
}
/**
* Checks if `chkPos` is inside a waterbox. If there is no water box below `chkPos`
* or if `chkPos` is above the water surface, return BGCHECK_Y_MIN, output
* environment properites to `envProp` if `chkPos` is inside the waterbox.
*/
-f32 Camera_GetWaterSurface(Camera* camera, Vec3f* chkPos, s32* envProp) {
+f32 Camera_GetWaterSurface(Camera* camera, Vec3f* chkPos, s32* lightIndex) {
PosRot playerPosRot;
f32 waterY;
WaterBox* waterBox;
@@ -563,7 +563,7 @@ f32 Camera_GetWaterSurface(Camera* camera, Vec3f* chkPos, s32* envProp) {
return BGCHECK_Y_MIN;
}
- *envProp = WaterBox_GetLightSettingIndex(&camera->play->colCtx, waterBox);
+ *lightIndex = WaterBox_GetLightIndex(&camera->play->colCtx, waterBox);
return waterY;
}
@@ -540,11 +540,11 @@ s32 Camera_GetWaterBoxBgCamIndex(Camera* camera, f32* waterY) {
}
/**
- * Checks if `chkPos` is inside a waterbox. If there is no water box below `chkPos`
- * or if `chkPos` is above the water surface, return BGCHECK_Y_MIN, output
- * environment properites to `envProp` if `chkPos` is inside the waterbox.
+ * Checks if `chkPos` is inside a waterbox.
+ * If there is no water box below `chkPos` or if `chkPos` is above the water surface, return BGCHECK_Y_MIN.
+ * If `chkPos` is inside the waterbox, output light index to `lightIndex`.
*/